#include <stdio.h>
#include <stdlib.h>


typedef struct _st_node {
    int val;
    struct _st_node *next;
} st_node;

typedef struct {
    st_node *tail;
} st_stack;


void stack_destroy(st_stack *stack)
{
    if (stack->tail) {
        st_node *p = stack->tail->next;
        stack->tail->next = 0;
        for (; p; p = p->next) free(p);
        stack->tail = 0;
    }
}


int stack_push(st_stack *stack, int value)
{
    st_node *p = (st_node *)malloc(sizeof (st_node));
    if (!p) return -1;

    if (stack->tail) {
        p->next = stack->tail->next;
        stack->tail->next = p;
    } else {
        p->next = p;
    }

    p->val = value;
    stack->tail = p;
    return 0;
}


int stack_pop(st_stack *stack, int *value)
{
    st_node *p = stack->tail;
    if (!p) return -1;

    *value = p->val;

    if (p->next == p) {
        free(p);
        stack->tail = 0;
    } else {
        while (p->next != stack->tail) p = p->next;
        p->next = p->next->next;
        free(stack->tail);
        stack->tail = p;
    }
    return 0;
}


void stack_dump(st_stack *stack)
{
    printf("stack: [");
    if (stack->tail) {
        st_node *p = stack->tail->next;
        for (; p != stack->tail; p = p->next) printf("%d, ", p->val);
        printf("%d]\n", p->val); 
    } else {
        printf("]\n");
    }
}


int main()
{
    st_stack stack = {0};
    int get;

    stack_push(&stack, 5);
    stack_push(&stack, 6);
    stack_push(&stack, 7);
    stack_push(&stack, 8);
    stack_dump(&stack);

    stack_pop(&stack, &get);
    printf("pop: %d\n", get);
    stack_pop(&stack, &get);
    printf("pop: %d\n", get);
    stack_dump(&stack);

    stack_push(&stack, 10);
    stack_push(&stack, 11);
    stack_push(&stack, 12);
    stack_dump(&stack);

    stack_destroy(&stack);
    stack_dump(&stack);

    return 0;
}
